%% Data Processing DT5 and FS5 task to account for difference in response rate

clear all; clc; 
global Dura Baseline Tm Tbase BSIZE Tbin DuraITI TmITI
tic
path='E:\Youna\Post-doc\MATLAB\Youna Matlab\DT Nex Files\RESULTfs5.xls'; %excel file with windows etc
[~,Session] = xlsread(path,'Windows','c23:c29');

%Main settings
BSIZE=0.01; %Do not change
Dura=[-25 20]; Tm=Dura(1):BSIZE:Dura(2);
DuraITI=[-50 20]; TmITI=DuraITI(1):BSIZE:DuraITI(2);
%Baseline=[-22 0]; Tbase=Baseline(1):BSIZE:Baseline(2); %now defined line 98
Tbin=-0.5:0.005:0.5; %window used to determine the optimal binsize
PStat=0.01; %for comparing pre versus post windows, or event A versus event B
MinNumTrials=5;
R=[];NN=0;
Nneurons=[];
Neur=0;
BinSize=0.05;
prewin =  [-1 0]; %BL window relative to LP1, for all events

thresholdIPI=[1,2,1];
task_Dataset={'RAW_DT5','RAW_FS5'};
task_Coord={'Coord_DT5','Coord_FS5'};
Sessions{1}={'s01-DT5','s02-DT5','s03-DT5','s04-DT5','s05-DT5','s06-DT5','s07-DT5','s08-DT5','s09-DT5','s10-DT5'};
Sessions{2}={'s01-FS5','s02-FS5','s03-FS5','s04-FS5','s05-FS5','s06-FS5','s07-FS5'};
EventName{1}={'First_LP','Third_LP','Last_LP'};
EventName{2}={'First_LPcomp','Intermediate_LP','Last_LP'};
task_sesOffset=[3,5];

%Smoothing
Smoothing=1; %0 for raw and 1 for smoothing
SmoothTYPE='lowess';
SmoothSPAN=5;
if Smoothing~=1, SmoothTYPE='NoSmoothing';SmoothSPAN=NaN; end



for task=1:2 % loop trough task
    load(task_Dataset{task})
    SessionName = {RAW.SessionName};
    Session=Sessions{task};
    %Finds the total number of neurons accross all sessions
    for i=1:length(Session) %loops through sessions
        Ses=strcmp(Session(i),SessionName);
        SesIndex=find(Ses==1);
        NN=0; Neur=0;
        R(task).Ses(i).Ninfo=[];
        
        for y=1:length(SesIndex)
            R(task).Ses(i).Ninfo=cat(1,R(task).Ses(i).Ninfo,RAW(SesIndex(y)).Ninfo);
            Neur=Neur+size(RAW(SesIndex(y)).Nrast,1);
            Nneurons(i)=Neur;
        end
        
        load(task_Coord{task});
        R(task).Ses(i).Coord=part(i+task_sesOffset(task)).Coord;
        R(task).Ses(i).Ninfo=cat(2, R(task).Ses(i).Ninfo, mat2cell([1:Nneurons(i)]',ones(1,Nneurons(i)),1));
        R(task).Ses(i).NumberTrials(1:Nneurons(i),1:3)=NaN(Nneurons(i),3);
    end
    
    
    %% runs the main routine
    for i=1:length(Session) %loops through sessions
        Ses=strcmp(Session(i),SessionName);
        SesIndex=find(Ses==1);
        NN=0;       
        for y=1:length(SesIndex)
            for j= 1:size(RAW(SesIndex(y)).Nrast,1) %Number of neurons per session
                
                NN=NN+1; %neuron counter
                if R(task).Ses(i).Coord(NN,4)~=0 %to avoid analyzing excluded neurons
                    
                    LP_Ind{1,1}=strcmp(EventName{task}{1},RAW(SesIndex(y)).Einfo(:,2));
                    LP_Ind{2,1}=strcmp(EventName{task}{2},RAW(SesIndex(y)).Einfo(:,2));
                    LP_Ind{3,1}=strcmp(EventName{task}{3},RAW(SesIndex(y)).Einfo(:,2));
                    LeverPress_Ind=strcmp('LeverPress',RAW(SesIndex(y)).Einfo(:,2));
                    
                    if task==1 % ref event for computation of the baseline
                        Eref=strcmp('LeverInsertion',RAW(SesIndex(y)).Einfo(:,2));
                    else
                        Eref=LP_Ind{1,1};
                    end
                    
                    FirstLP=RAW(SesIndex(y)).Erast{LP_Ind{1,1}};
                    IntLP=RAW(SesIndex(y)).Erast{LP_Ind{2,1}};
                    LastLP=RAW(SesIndex(y)).Erast{LP_Ind{3,1}};
                    LeverPress=RAW(SesIndex(y)).Erast{LeverPress_Ind};
                    
                    
                    for k=1:length(LastLP)
                        R(task).Ses(i).IPI{NN,1}(k,1)=LeverPress(find(LeverPress>FirstLP(k,1),1,'first'))-FirstLP(k,1);
                        R(task).Ses(i).IPI{NN,2}(k,1)=LeverPress(find(LeverPress>IntLP(k,1),1,'first'))-LeverPress(find(LeverPress<IntLP(k,1),1,'last'));
                        R(task).Ses(i).IPI{NN,3}(k,1)=LastLP(k,1)-LeverPress(find(LeverPress<LastLP(k,1),1,'last'));
                    end
                    LPs={};
                    for press=1:3
                        clear selectionTrial
                        if ~isempty(RAW(SesIndex(y)).Erast{LP_Ind{press,1}})
                            selectionTrial=R(task).Ses(i).IPI{NN,press}<thresholdIPI(press);
                            R(task).Ses(i).NumberTrials(NN,press)=sum(selectionTrial);
                            if R(task).Ses(i).NumberTrials(NN,press)>MinNumTrials
                                LPs{press,1}=RAW(SesIndex(y)).Erast{LP_Ind{press,1}}(selectionTrial,1);
                                Tbase=prewin(1,1):BSIZE:prewin(1,2); % for DT5 and FS5, same prewin for all events
                                % PSTH around press for all trial- 0.05s binsize
                                [PSR4,N4]=MakePSR04(RAW(SesIndex(y)).Nrast(j),LPs{press,1},Dura,{1});
                                [PSR0,N0]=MakePSR04(RAW(SesIndex(y)).Nrast(j),RAW(SesIndex(y)).Erast{Eref},prewin(1,:),{1});% BL is [-1 0] from LP1
                                [PTH4,BW1,~]=MakePTH07(PSR4,repmat(N4, size(RAW(SesIndex(y)).Nrast{j},1),1),{2,0,BinSize});
                                [PTH0,~,~]=MakePTH07(PSR0,repmat(N0, size(RAW(SesIndex(y)).Nrast{j},1),1),{1,0,BinSize});
                                
                                PTH4=smooth(PTH4,SmoothSPAN,SmoothTYPE)';
                                PTH0=smooth(PTH0,SmoothSPAN,SmoothTYPE)';
                                
                                R(task).Ses(i).PSTHz{1,press}(NN,1:length(Tm))=normalize(PTH4,PTH0,0);
                            end % if Ntrial>5
                            
                            fprintf('Neuron ID # %d\n',NN);
                        end
                    end
                elseif R(task).Ses(i).Coord(NN,4)~=0
                end %exclusion: IF R.Structure(NN)~=0 to avoid analyzing excluded neurons
            end %neurons: FOR j= 1:size(RAW(i).Nrast,1)
        end %  FOR i=1:length(RAW)
    end
end

save('R_Comparison_2task.mat','R');





















